@@ -5,7 +5,7 @@
 
 /*
     This file is part of Advanced Strategic Command; http://www.asc-hq.de
-    Copyright (C) 1994-2003  Martin Bickel  and  Marc Schellenberger
+    Copyright (C) 1994-2005  Martin Bickel  and  Marc Schellenberger
 
     This program is free software; you can redistribute it and/or modify
     it under the terms of the GNU General Public License as published by
@@ -114,8 +114,7 @@ float AttackFormula :: strength_hemming ( int  ax,  int ay,  pvehicle d_eht )
 
 float AttackFormula :: strength_damage ( int damage )
 {
-   float a = (300 - 2 * damage) / 3;
-   return a / 100;
+   return 1 - (2.0 * float(damage) / 300.0);
 }
 
 float AttackFormula :: strength_experience ( int experience )
