@@ -4,9 +4,18 @@
 */
 
 
-//     $Id: basestrm.h,v 1.59 2004/05/29 15:07:37 mbickel Exp $
+//     $Id: basestrm.h,v 1.61 2005/04/29 17:57:12 mbickel Exp $
 //
 //     $Log: basestrm.h,v $
+//     Revision 1.61  2005/04/29 17:57:12  mbickel
+//      Prepared 1.16 release
+//      Added object translation
+//
+//     Revision 1.60  2005/04/24 10:09:30  mbickel
+//      Added object growth
+//      Updated version numbers
+//      Fixed mine and object removal
+//
 //     Revision 1.59  2004/05/29 15:07:37  mbickel
 //      Fixed maps
 //      Fixed crash with asc.cache
@@ -652,7 +661,7 @@ class tfindfile {
 
                name = stream.readString();
                directoryLevel = stream.readInt();
-               isInContainer = stream.readInt();
+               isInContainer = stream.readInt() != 0;
                location = stream.readString();
                size = stream.readInt();
                date = stream.readInt();
@@ -764,6 +773,7 @@ extern char* extractFileName ( char* buf, const char* filename );
 extern ASCString extractFileName ( const ASCString& filename );
 extern ASCString extractFileName_withoutSuffix ( const ASCString& filename );
 extern int createDirectory ( const char* name );
+extern int getSearchPathNum();
 extern ASCString getSearchPath ( int i );
 
 //! converts path delimitters from foreign operating systems to the ones used by the current operating system. On Linux, this function converts backslashes to slashes, on Windows vice versa
