@@ -210,8 +210,10 @@ void         tsearchputbuildingfields::testfield(const MapCoordinate& mc)
 void         putbuildinglevel1(void)
 {
 
-   tkey                       taste;
+   tkey                       taste=0;
    pvehicle                   eht;
+   int                        keyprn=0;
+   tkey                       input=0;
 
    eht = getactfield()->vehicle;
 
@@ -236,8 +238,6 @@ void         putbuildinglevel1(void)
    mousevisible(true);
    do {
       if ( keypress() ) {
-         int keyprn;
-         tkey input;
          getkeysyms( &input, &keyprn );
          selectbuildinggui.checkforkey(taste, keyprn );
       }
@@ -450,7 +450,7 @@ void         destructbuildinglevel2( int xp, int yp)
 void         tputmine::testfield(const MapCoordinate& mc)
 {
    pfield fld = gamemap->getField(mc);
-   if ( !fld->vehicle  &&  !fld->building ) {
+   if ( !fld->vehicle  &&  !fld->building && fieldvisiblenow( fld, player )) {
       fld->a.temp = 0;
       if ( !fld->mines.empty() ) {
          fld->a.temp += 2;
@@ -800,6 +800,9 @@ void         tbuildstreet::testfield( const MapCoordinate& mc )
 {
    pfield fld = gamemap->getField(mc);
 
+   if ( !fieldvisiblenow( fld, actvehicle->getOwner()))
+      return;
+
    obj = new tobjectcontainers_buildable_on_field ( mc.x, mc.y );
    objects_buildable.field[ objects_buildable.fieldnum++ ] = obj;
 
@@ -1367,10 +1370,11 @@ int  tsearchreactionfireingunits :: checkfield ( const MapCoordinate3D& pos, pve
    for ( int i = 0; i < 8; i++ )
       evaluatevisibilityfield ( actmap, fld, i, -1, actmap->getgameparameter ( cgp_initialMapVisibility ) );
 
-   vehicle->height = oldheight;
-
    if ( result )
       vehicle = NULL;
+   else
+      vehicle->height = oldheight;
+      
 
    return attacks;
 }
