@@ -37,7 +37,7 @@
  #include "password.h"
 
 //! The number of game paramters that can be specified for each map.
-const int gameparameternum = 29;
+const int gameparameternum = 32;
 
 //! The names of the game paramter. \sa gameparameterdefault
 extern const char* gameparametername[ gameparameternum ];
@@ -76,22 +76,35 @@ enum GameParameter { cgp_fahrspur,
        cgp_experienceDivisorAttack,
        cgp_disableDirectView,
        cgp_disableUnitTransfer,
-       cgp_experienceDivisorDefense };
+       cgp_experienceDivisorDefense,
+       cgp_debugEvents,
+       cgp_objectGrowthMultiplier,
+       cgp_objectGrowOnOtherObjects };
 
 
+class AgeableItem {
+    protected:
+       AgeableItem() : lifetimer(-1) {};
+    public:
+       int lifetimer;
+
+       //! ages the object by one turn. Returns true if the object shall be removed
+       static bool age( AgeableItem& obj );
+};
+
 //! an instance of an object type (#tobjecttype) on the map
-class Object {
+class Object : public AgeableItem {
     public:
        pobjecttype typ;
        int damage;
        int dir;
-       int time;
        // int dummy[4];
        Object ( void );
        Object ( pobjecttype t );
        void display ( int x, int y, int weather = 0 );
        void setdir ( int dir );
        int  getdir ( void );
+
 };
 
 #define cminenum 4
@@ -101,17 +114,17 @@ extern const int MineBasePunch[cminenum]  ;
 enum MineTypes { cmantipersonnelmine = 1 , cmantitankmine, cmmooredmine, cmfloatmine  };
 
 
-class Mine {
+class Mine : public AgeableItem {
    public:
+      Mine( MineTypes type, int strength, int player, tmap* gamemap );
+
+
       MineTypes type;
 
       //! the effective punch of the mine
       int strength;
 
-      //! the turnnumber in which the mine was placed
-      int time;
-
-      //! the player who placed the mine; range 0 .. 7      
+      //! the player who placed the mine; range 0 .. 7
       int player;
 
       //! can the mine attack this unit
@@ -123,7 +136,7 @@ class LoadNextMap {
        public:
           int id;
           LoadNextMap( int ID ) : id(ID) {};
-};          
+};
 
 
 
@@ -244,9 +257,6 @@ class  tfield {
     //! the player who placed the mines on this field.
     int mineowner ( void );
 
-    //! mines may have a limited lifetime. This methods removes all mines whose maxmimum lifetime is exeeded
-    void checkminetime ( int time );
-
     //! checks if the unit is standing on this field. Since units are being cloned for some checks, this method should be used instead of comparing the pointers to the unit
     bool unitHere ( const Vehicle* veh );
 
@@ -261,6 +271,8 @@ class  tfield {
     **/
     void  removemine ( int num ); 
 
+    void endRound( int turn );
+
     //! some variables for the viewcalculation algorithm. see #viewcalculation.cpp for details
     struct View {
       int view;
@@ -296,6 +308,7 @@ class  tfield {
 //! The map. THE central structure of ASC, which holds everything not globally available together
 class tmap {
       void operator= ( const tmap& map );
+
    public:
       //! the size of the map
       int          xsize, ysize;
@@ -659,8 +672,16 @@ class tmap {
 
       //! just a helper variable for loading the map; no function outside;
       bool loadOldEvents;
+
+      //! generated a pseudo-random number with the map-internal seed
+      int random( int max );
+
    private:
       pvehicle getUnit ( pvehicle eht, int nwid );
+
+      void objectGrowth();
+
+      unsigned int randomSeed;
 };
 
 typedef tmap::Player Player;
