@@ -109,21 +109,34 @@ int scrleftspace = 21;
 
 void copyvfb2displaymemory_zoom ( void* parmbuf, int x1, int y1, int x2, int y2 )
 {
+  struct parmstruct {
+          long src;
+          long dst;
+          int x;
+          int y;
+          int* steps;
+          int srcdif;
+          int dstdif;
+          int* vfbsteps;
+      };
+   
    int tempdirectscreenaccess = agmp->directscreenaccess;
    if ( hgmp->directscreenaccess != agmp->directscreenaccess )
       agmp->directscreenaccess = hgmp->directscreenaccess;
 
-   int* parmi = (int*) parmbuf;
+      
+   parmstruct* parm;
+   parm = (parmstruct *)parmbuf;
+   
+   char* esi = (char*) parm->src;
+   char* edi = (char*) parm->dst;
 
-   char* esi = (char*) parmi[0];
-   char* edi = (char*) parmi[1];
-
-   int edx = parmi[3];
+   int edx = parm->y;
    int ecx;
    int* ebp;
    do {
-      ebp = (int*) parmi[4];
-      ecx =  parmi[2];
+      ebp = parm->steps;
+      ecx =  parm->x;
       do {
 
          esi += *ebp;
@@ -135,9 +148,9 @@ void copyvfb2displaymemory_zoom ( void* parmbuf, int x1, int y1, int x2, int y2
 
       } while ( ecx ); /* enddo */
 
-      esi += parmi[5];
-      edi += parmi[6];
-      ebp = (int*) parmi[7];
+      esi += parm->srcdif;
+      edi += parm->dstdif;
+      ebp = parm->vfbsteps;
 
       edx--;
       esi += ebp[edx];
@@ -657,8 +670,8 @@ void tdisplaymap :: cp_buf ( void )
 
 
        struct {
-          int src;
-          int dst;
+          long src;
+          long dst;
           int x;
           int y;
           int* steps;
@@ -686,8 +699,8 @@ void tdisplaymap :: cp_buf ( int x1, int y1, int x2, int y2 )
 {
 
        struct {
-          int src;
-          int dst;
+          long src;
+          long dst;
           int x;
           int y;
           int* steps;
@@ -1982,4 +1995,3 @@ int tbackgroundpict :: getlastpaintmode ( void )
 
 #endif
 
-
