@@ -49,6 +49,8 @@ ObjectType :: ObjectType ( void )
    viewbonus_plus = 0;
    imageHeight = 0;
    physicalHeight = 0;
+   growthRate = 0;
+   lifetime = -1;
 }
 
 ObjectType::FieldModification&  ObjectType::getFieldModification ( int weather )
@@ -802,7 +804,7 @@ void         calculateallobjects( pmap actmap )
 
 
 
-const int object_version = 11;
+const int object_version = 13;
 
 void ObjectType :: read ( tnstream& stream )
 {
@@ -878,9 +880,19 @@ void ObjectType :: read ( tnstream& stream )
        stream.readrlepict ( &buildicon,  false, &w);
        stream.readrlepict ( &removeicon, false, &w);
 
-
        techDependency.read ( stream );
 
+       if ( version >= 12 )
+          growthRate = stream.readFloat();
+       else
+          growthRate = 0;
+
+       if ( version >= 13 )
+          lifetime = stream.readInt();
+       else
+          lifetime = -1;
+
+
        for ( int ww = 0; ww < cwettertypennum; ww++ )
          if ( weather.test ( ww ) ) {
 
@@ -919,35 +931,36 @@ void ObjectType :: setupImages()
    #ifndef converter
    for ( int ww = 0; ww < cwettertypennum; ww++ )
       if ( weather.test( ww ) )
-         for ( int n = 0; n < weatherPicture[ww].bi3pic.size(); n++ ) {
-            if ( weatherPicture[ww].flip[n] == 1 ) {
-               void* buf = new char [ imagesize ( 0, 0, fieldxsize, fieldysize ) ];
-               flippict ( weatherPicture[ww].images[n], buf , 1 );
-               asc_free ( weatherPicture[ww].images[n] );
-               weatherPicture[ww].images[n] = buf;
-               copycount++;
-            }
+         for ( int n = 0; n < weatherPicture[ww].bi3pic.size(); n++ )
+			   if ( weatherPicture[ww].flip.size() > n ) {
+               if ( weatherPicture[ww].flip[n] == 1 ) {
+                  void* buf = new char [ imagesize ( 0, 0, fieldxsize, fieldysize ) ];
+                  flippict ( weatherPicture[ww].images[n], buf , 1 );
+                  asc_free ( weatherPicture[ww].images[n] );
+                  weatherPicture[ww].images[n] = buf;
+                  copycount++;
+               }
 
-            if ( weatherPicture[ww].flip[n] == 2 ) {
-               void* buf = new char [ imagesize ( 0, 0, fieldxsize, fieldysize ) ];
-               flippict ( weatherPicture[ww].images[n], buf , 2 );
-               asc_free ( weatherPicture[ww].images[n] );
-               weatherPicture[ww].images[n] = buf;
-               copycount++;
-            }
+               if ( weatherPicture[ww].flip[n] == 2 ) {
+                  void* buf = new char [ imagesize ( 0, 0, fieldxsize, fieldysize ) ];
+                  flippict ( weatherPicture[ww].images[n], buf , 2 );
+                  asc_free ( weatherPicture[ww].images[n] );
+                  weatherPicture[ww].images[n] = buf;
+                  copycount++;
+               }
 
-            if ( weatherPicture[ww].flip[n] == 3 ) {
-               void* buf = new char [ imagesize ( 0, 0, fieldxsize, fieldysize ) ];
-               flippict ( weatherPicture[ww].images[n], buf , 2 );
-               flippict ( buf, weatherPicture[ww].images[n], 1 );
-               asc_free( buf );
-               copycount++;
-            }
+               if ( weatherPicture[ww].flip[n] == 3 ) {
+                  void* buf = new char [ imagesize ( 0, 0, fieldxsize, fieldysize ) ];
+                  flippict ( weatherPicture[ww].images[n], buf , 2 );
+                  flippict ( buf, weatherPicture[ww].images[n], 1 );
+                  asc_free( buf );
+                  copycount++;
+               }
 
 
 //            if ( weatherPicture[ww].bi3pic[n] == -1 )
 //               weatherPicture[ww].flip[n] = 0;
-         }
+            }
    #endif
 
    /*
@@ -1026,6 +1039,9 @@ void ObjectType :: write ( tnstream& stream ) const
 
     techDependency.write ( stream );
 
+    stream.writeFloat( growthRate );
+    stream.writeInt( lifetime );
+
 
     for ( int ww = 0; ww < cwettertypennum; ww++ )
        if ( weather.test( ww ) ) {
@@ -1048,9 +1064,9 @@ void ObjectType :: write ( tnstream& stream ) const
 void ObjectType :: FieldModification :: runTextIO ( PropertyContainer& pc )
 {
    pc.addDFloatArray ( "Movemalus_plus", movemalus_plus );
-   int mm = movemalus_plus.size();
+   size_t mm = movemalus_plus.size();
    movemalus_plus.resize( cmovemalitypenum );
-   for ( int i = mm; i < cmovemalitypenum; i++ ) {
+   for ( size_t i = mm; i < cmovemalitypenum; i++ ) {
       if ( i == 0 )
          movemalus_plus[i] = 0;
       else
@@ -1061,7 +1077,7 @@ void ObjectType :: FieldModification :: runTextIO ( PropertyContainer& pc )
    pc.addDFloatArray ( "Movemalus_abs", movemalus_abs );
    mm = movemalus_abs.size();
    movemalus_abs.resize( cmovemalitypenum );
-   for ( int i = mm; i < cmovemalitypenum; i++ ) {
+   for ( size_t i = mm; i < cmovemalitypenum; i++ ) {
       if ( i == 0 )
          movemalus_abs[i] = -1;
       else
@@ -1136,6 +1152,9 @@ void ObjectType :: runTextIO ( PropertyContainer& pc )
 
    pc.addString( "Name", name );
 
+   pc.addDFloat( "GrowthRate", growthRate, 0 );
+   pc.addInteger( "LifeTime", lifetime, -1 );
+
    pc.addTagInteger ( "NetBehaviour", netBehaviour, netBehaviourNum, objectNetMethod, int(0) );
 
    if ( pc.isReading() && pc.find ( "NoSelfChaining" )) {
@@ -1203,7 +1222,7 @@ void ObjectType :: runTextIO ( PropertyContainer& pc )
                pc.addIntegerArray ( "ImageReference", imgReferences );
 
                for ( int j = 0; j < weatherPicture[i].images.size(); j++ )
-                  if ( imgReferences[j] >= 0 && imgReferences[j] < weatherPicture[i].images.size() ) {
+                  if ( imgReferences.size() > j && imgReferences[j] >= 0 && imgReferences[j] < weatherPicture[i].images.size() ) {
                      if ( weatherPicture[i].images[j] )
                         asc_free ( weatherPicture[i].images[j] );
                      int newimg = imgReferences[j];
