@@ -129,6 +129,12 @@
 
 
 
+#ifdef WIN32
+ #include  "win32/msvc/mdump.h"
+ MiniDumper miniDumper( "main" );
+#endif
+
+
 class tsgonlinemousehelp : public tonlinemousehelp
 {
    public:
@@ -587,7 +593,8 @@ enum tuseractions { ua_repainthard,     ua_repaint, ua_help, ua_showpalette, ua_
                     ua_toggleunitshading, ua_computerturn, ua_setupnetwork, ua_howtostartpbem, ua_howtocontinuepbem, ua_mousepreferences,
                     ua_selectgraphicset, ua_UnitSetInfo, ua_GameParameterInfo, ua_GameStatus, ua_viewunitweaponrange, ua_viewunitmovementrange,
                     ua_aibench, ua_networksupervisor, ua_selectPlayList, ua_soundDialog, ua_reloadDlgTheme, ua_showPlayerSpeed, ua_renameunit,
-                    ua_statisticdialog, ua_viewPipeNet, ua_cancelResearch, ua_showResearchStatus, ua_exportUnitToFile, ua_cargosummary, ua_showsearchdirs };
+                    ua_statisticdialog, ua_viewPipeNet, ua_cancelResearch, ua_showResearchStatus, ua_exportUnitToFile, ua_cargosummary, ua_showsearchdirs,
+                    ua_unitsummary, ua_togglesound };
 
 
 class tsgpulldown : public tpulldown
@@ -607,6 +614,8 @@ void         tsgpulldown :: init ( void )
    addbutton ( "~M~ouse options", ua_mousepreferences );
    #ifndef NO_PARAGUI
    addbutton ( "~S~ound options", ua_soundDialog );
+   #else
+   addbutton ( "sound on/off", ua_togglesound );
    #endif
    addbutton ( "seperator", -1);
    addbutton ( "E~x~itctrl-x", ua_exitgame );
@@ -644,6 +653,7 @@ void         tsgpulldown :: init ( void )
    addbutton ( "~R~esearch", ua_researchinfo );
    addbutton ( "~P~lay time", ua_showPlayerSpeed );
    addbutton ( "~C~argo Summary", ua_cargosummary );
+   addbutton ( "Unit Summary", ua_unitsummary );
    // addbutton ( "~R~esearch status", ua_showResearchStatus );
 
    // addbutton ( "vehicle ~I~mprovementF7", ua_dispvehicleimprovement);
@@ -1151,7 +1161,7 @@ void viewunitmovementrange ( pvehicle veh, tkey taste )
 {
    if ( veh && !moveparams.movestatus && fieldvisiblenow ( getfield ( veh->xpos, veh->ypos ))) {
       actmap->cleartemps ( 7 );
-      TemporaryContainerStorage tcs ( veh, true );
+      TemporaryContainerStorage tcs ( veh, false );
       veh->reactionfire.disable();
       veh->setMovement ( veh->typ->movement[log2(veh->height)]);
       int oldcolor = veh->color;
@@ -1190,7 +1200,9 @@ void viewunitmovementrange ( pvehicle veh, tkey taste )
          }
       }
       veh->color = oldcolor;
+      
       tcs.restore();
+      
    }
 }
 
@@ -1216,15 +1228,11 @@ void calcCargoSummary( ContainerBase* cb, map<int,int>& summary )
       }
 }
 
-void showCargoSummary()
-{
    typedef map<int,int> Summary;
-   Summary summary;
 
-   pfield fld = getactfield();
-   if ( fld && fld->vehicle && fld->vehicle->getOwner() == actmap->actplayer ) {
-      calcCargoSummary( fld->vehicle, summary );
 
+void showSummary ( map<int,int>& summary )
+{
       ASCString s;
 
       map<ASCString, int> sorter;
@@ -1236,12 +1244,44 @@ void showCargoSummary()
          s += i->first + ": " + strrr(i->second) + "\n";
 
       tviewanytext vat ;
-      vat.init ( "Cargo information", s.c_str(), 20, -1 , 450, 480 );
+      vat.init ( "Unit summary", s.c_str(), 20, -1 , 450, 480 );
       vat.run();
       vat.done();
+
+}
+
+void showCargoSummary()
+{
+   Summary summary;
+
+   pfield fld = getactfield();
+   if ( fld && fld->vehicle && fld->vehicle->getOwner() == actmap->actplayer ) {
+      calcCargoSummary( fld->vehicle, summary );
+      showSummary( summary );
    }
 }
 
+void showUnitSummary()
+{
+   Summary summary;
+
+   for ( int y = 0; y < actmap->ysize; ++y )
+      for ( int x = 0; x < actmap->xsize; ++x ) {
+         pfield fld = actmap->getField(x,y);
+         if ( fld ) {
+            if ( fld->vehicle && fld->vehicle->getOwner() == actmap->actplayer ) {
+               calcCargoSummary( fld->vehicle, summary );
+               summary[ fld->vehicle->typ->id] += 1;
+            }
+            if ( fld->building && fld->building->getOwner() == actmap->actplayer && (fld->bdt & getTerrainBitType(cbbuildingentry)).any() ) 
+               calcCargoSummary( fld->getContainer(), summary );
+         }
+      }
+
+   showSummary( summary );
+}
+
+
 
 void showSearchPath()
 {
@@ -1627,6 +1667,16 @@ void execuseraction ( tuseractions action )
       case ua_soundDialog:
          soundSettings();
          break;
+      case ua_togglesound:
+         if ( !SoundSystem::getInstance()->isOff() ) {
+            bool on = !SoundSystem::getInstance()->areEffectsMuted();
+            SoundSystem::getInstance()->setEffectsMute( on );
+            if ( on )
+               SoundSystem::getInstance()->pauseMusic();
+            else
+               SoundSystem::getInstance()->resumeMusic();
+         }
+         break;
       case ua_showPlayerSpeed:
          showPlayerTime();
          break;
@@ -1705,6 +1755,8 @@ void execuseraction ( tuseractions action )
          break;
          case ua_cargosummary: showCargoSummary();
          break;
+         case ua_unitsummary: showUnitSummary();
+            break;
          case ua_showsearchdirs: showSearchPath();
          break;
 
