@@ -1,4 +1,4 @@
-//     $Id: typen.h,v 1.155 2005/01/06 19:39:37 mbickel Exp $
+//     $Id: typen.h,v 1.157 2005/04/24 10:09:31 mbickel Exp $
 
 /*
      This file is part of Advanced Strategic Command; http://www.asc-hq.de
@@ -738,7 +738,7 @@ const int submarineMovement = 11;
 #define destructoutput 5
 #define nowindplanefuelusage 1      // herrscht kein Wind, braucht ein Flugzeug pro Runde soviel Sprit wie das fliegend dieser Anzahl fielder
   //   #define maxwindplainfuelusage 32   // beim nextturn: tank -= fuelconsumption * (maxwindplainfuelusage*nowindplainfuelusage + windspeed) / maxwindplainfuelusage     
-const int maxwindspeed = 60;          // Wind with a strength of 255 means that the air moves 12 fields / turn
+const int maxwindspeed = 60;          // Wind with a strength of 255 means that the air moves 6 fields / turn
 
 
 #define generatortruckefficiency 2  // fuer jede vehicle Power wird soviel Sprit gebraucht !
@@ -784,8 +784,6 @@ const int maxminingrange = 10;
 const float productionLineConstructionCostFactor = 0.5;
 const float productionLineRemovalCostFactor = 0.2;
 
-//! The weight of 1000 units of a Resource
-extern const int resourceWeight[ resourceTypeNum ];
 
 #define objectbuildmovecost 16  // vehicle->movement -= (8 + ( fld->movemalus[0] - 8 ) / ( objectbuildmovecost / 8 ) ) * kosten des obj
 
