@@ -367,13 +367,19 @@ void Vehicle :: endRound ( void )
    }
 }
 
-void Vehicle :: endTurn( void )
+void Vehicle :: endAnyTurn()
+{
+   reactionfire.endAnyTurn();
+}
+
+
+void Vehicle :: endOwnTurn()
 {
    if ( typ->autorepairrate > 0 )
       if ( damage )
          repairItem ( this, max ( damage - typ->autorepairrate, 0 ) );
 
-   reactionfire.endTurn();
+   reactionfire.endOwnTurn();
 
    if ( !gamemap->getField(getPosition())->unitHere(this)) {
       int mx = -1;
@@ -400,7 +406,6 @@ void Vehicle :: endTurn( void )
          }
       }
 
-
    resetMovement();
    attacked = false;
 
@@ -455,7 +460,7 @@ void Vehicle :: setMovement ( int newmove, double cargoDivisor )
                if ( cargoDivisor )
                   lperc /= cargoDivisor;
 
-               loading[i]->decreaseMovement ( int( lperc * loading[i]->typ->movement[ log2 ( loading[i]->height)] ));
+               loading[i]->decreaseMovement ( max( 1, int( ceil( lperc * double(loading[i]->typ->movement[ log2 ( loading[i]->height)] )))));
             }
          } /* endfor */
    }
@@ -646,9 +651,13 @@ void Vehicle::ReactionFire::disable ( void )
    }
 }
 
+void Vehicle::ReactionFire::endAnyTurn()
+{
+   resetShotCount();
+}
 
 
-void Vehicle::ReactionFire::endTurn ( void )
+void Vehicle::ReactionFire::endOwnTurn()
 {
    if ( status != off ) {
       if ( status == init1a )
@@ -662,7 +671,6 @@ void Vehicle::ReactionFire::endTurn ( void )
       else
          enemiesAttackable = 0;
    }
-   resetShotCount();
    nonattackableUnits.clear();
 }
 
