@@ -856,7 +856,15 @@ void Vehicletype::runTextIO ( PropertyContainer& pc )
    if ( pc.find ( "WreckageObject" ) || !pc.isReading() )
       pc.addIntegerArray("WreckageObject", wreckageObject );
 
-   pc.addDFloat("CargoMovementDivisor", cargoMovementDivisor, 2 );
+
+   if ( pc.find( "CargoMovementDivisor" ))
+      pc.addDFloat("CargoMovementDivisor", cargoMovementDivisor);
+   else {
+      pc.openBracket( "Transportation" );
+      pc.addDFloat("CargoMovementDivisor", cargoMovementDivisor, 2 );
+      pc.closeBracket();
+   }
+
 
    pc.addInteger("Weight",  weight);
    pc.openBracket("TerrainAccess" );
@@ -1099,11 +1107,11 @@ Resources Vehicletype :: calcProductionsCost()
 			typecostm += armor*10;
 		} else
 		if ( movemalustyp == MoveMalusType::light_aircraft || movemalustyp == MoveMalusType::medium_aircraft || movemalustyp == MoveMalusType::heavy_aircraft || movemalustyp == MoveMalusType::helicopter ) {
-			typecoste += armor*16;
-			typecostm += armor*16;
+			typecoste += armor*20;
+			typecostm += armor*20;
 		} else {
-			typecoste += armor*5;
-			typecostm += armor*5;
+			typecoste += armor*6;
+			typecostm += armor*6;
 		}
 
 		// Zuschlag fr Eisbrecher
@@ -1131,13 +1139,19 @@ Resources Vehicletype :: calcProductionsCost()
 			typecoste += maxLoadableUnits*100;
 			typecostm += maxLoadableUnits*100;
 
+         bool carrierCharge = false;
+
 			// Zuschlag fr Flugzeugtrger / Start- und Landeeinrichtungen
-			for ( int T=0; T < entranceSystems.size(); ++T ) {
-				if ( entranceSystems[T].container_height == chfahrend && entranceSystems[T].height_abs == chtieffliegend && maxLoadableUnits > 2 ) {
-					typecoste += maxLoadableUnits*800;
-					typecostm += maxLoadableUnits*800;
-				}
-			}
+			for ( int T=0; T < entranceSystems.size(); ++T ) 
+				if ( entranceSystems[T].container_height < chtieffliegend 
+                  && (entranceSystems[T].height_abs & (chtieffliegend | chfliegend | chhochfliegend | chsatellit))
+                  && maxLoadableUnits > 2 )
+               carrierCharge = true;
+
+         if ( carrierCharge ) {
+		      typecoste += maxLoadableUnits*1000;
+				typecostm += maxLoadableUnits*1000;
+         }
 		}
 		// Check maximale Reichweite
 		for ( int M=0; M < movement.size(); ++M ) {
@@ -1147,24 +1161,24 @@ Resources Vehicletype :: calcProductionsCost()
 		}
 		// Zuschlag fr Triebwerke
 		if (movecostsize > 70 ) {
-			typecoste += (movecostsize-70)*30;
-			typecostm += (movecostsize-70)*15;
+			typecoste += (movecostsize-70)*15;
+			typecostm += (movecostsize-70)*5;
 		}
 		
 		// Zuschlag fr Flugzeugtriebwerke
 		if (movecostsize > 120 ) {
 			typecoste += (movecostsize-120)*10;
-			typecostm += (movecostsize-120)*5;
+			typecostm += (movecostsize-120)*10;
 		}
 		// Zuschlag fr Hochleistungsflugzeugtriebwerke
 		if (movecostsize > 170 ) {
-			typecoste += (movecostsize-170)*5;
-			typecostm += (movecostsize-170)*5;
+			typecoste += (movecostsize-170)*12;
+			typecostm += (movecostsize-170)*12;
 		}
 		// Zuschlag fr Spezialflugzeugtriebwerke
 		if (movecostsize > 200 ) {
-			typecoste += (movecostsize-200)*10;
-			typecostm += (movecostsize-200)*10;
+			typecoste += (movecostsize-200)*14;
+			typecostm += (movecostsize-200)*14;
 		}
 
 
@@ -1224,17 +1238,17 @@ Resources Vehicletype :: calcProductionsCost()
 			// Waffenreichweitenzuschlag Kurzstrecke
 			if (rangecostsize > 19 ) {
 				weaponcoste += (rangecostsize-10)*80;
-				weaponcostm += (rangecostsize-10)*50;
+				weaponcostm += (rangecostsize-10)*70;
 			}
 			// Waffenreichweitenzuschlag Mittelstrecke
 			if (rangecostsize > 69 ) {
-				weaponcoste += (rangecostsize-60)*100;
-				weaponcostm += (rangecostsize-60)*80;
+				weaponcoste += (rangecostsize-60)*150;
+				weaponcostm += (rangecostsize-60)*100;
 			}
 			// Waffenreichweitenzuschlag Langstrecke
 			if (rangecostsize > 99 ) {
-				weaponcoste += (rangecostsize-90)*110;
-				weaponcostm += (rangecostsize-90)*100;
+				weaponcoste += (rangecostsize-90)*200;
+				weaponcostm += (rangecostsize-90)*200;
 			}
 		}
 
@@ -1352,14 +1366,14 @@ Resources Vehicletype :: calcProductionsCost()
 
 		// low movement
 		if (movecostsize < 20 ) {
-			res.energy -= typecoste/5;
-			res.material -= typecostm/6;
+			res.energy -= typecoste/4;
+			res.material -= typecostm/4;
 		}
 
 		// low movement
 		if (movecostsize < 10 ) {
-			res.energy -= typecoste/5;
-			res.material -= typecostm/6;
+			res.energy -= typecoste/4;
+			res.material -= typecostm/4;
 		}
 
 
